pub struct ProofAuth {
pub id: ProofId,
}Expand description
A RAII type that holds a reference to a proof that is authorized for use. Once this is dropped the proof goes out of scope and can no longer be used.
Fields
id: ProofIdTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ProofAuth
impl<'de> Deserialize<'de> for ProofAuth
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more