pub fn register_panic_hook()Expand description
Registers a std::panic hook that tries to include the error line and column to the error
pub fn register_panic_hook()Registers a std::panic hook that tries to include the error line and column to the error